%%%Generate PgSNP GUI
function varargout = PgSNP(varargin)
% PGSNP M-file for PgSNP.fig
%      PGSNP, by itself, creates a new PGSNP or raises the existing
%      singleton*.
%
%      H = PGSNP returns the handle to a new PGSNP or the handle to
%      the existing singleton*.
%
%      PGSNP('CALLBACK',hObject,eventData,handles,...) calls the local
%      function named CALLBACK in PGSNP.M with the given input arguments.
%
%      PGSNP('Property','Value',...) creates a new PGSNP or raises the
%      existing singleton*.  Starting from the left, property value pairs are
%      applied to the GUI before PgSNP_OpeningFcn gets called.  An
%      unrecognized property name or invalid value makes property application
%      stop.  All inputs are passed to PgSNP_OpeningFcn via varargin.
%
%      *See GUI Options on GUIDE's Tools menu.  Choose "GUI allows only one
%      instance to run (singleton)".
%
% See also: GUIDE, GUIDATA, GUIHANDLES

% Edit the above text to modify the response to help PgSNP

% Last Modified by GUIDE v2.5 14-May-2011 20:05:07

% Begin initialization code - DO NOT EDIT
gui_Singleton = 1;
gui_State = struct('gui_Name',       mfilename, ...
                   'gui_Singleton',  gui_Singleton, ...
                   'gui_OpeningFcn', @PgSNP_OpeningFcn, ...
                   'gui_OutputFcn',  @PgSNP_OutputFcn, ...
                   'gui_LayoutFcn',  [] , ...
                   'gui_Callback',   []);
if nargin && ischar(varargin{1})
    gui_State.gui_Callback = str2func(varargin{1});
end

if nargout
    [varargout{1:nargout}] = gui_mainfcn(gui_State, varargin{:});
else
    gui_mainfcn(gui_State, varargin{:});
end
% End initialization code - DO NOT EDIT


% --- Executes just before PgSNP is made visible.
function PgSNP_OpeningFcn(hObject, eventdata, handles, varargin)
% This function has no output args, see OutputFcn.
% hObject    handle to figure
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
% varargin   command line arguments to PgSNP (see VARARGIN)

% Choose default command line output for PgSNP
handles.output = hObject;

% Update handles structure
guidata(hObject, handles);

% UIWAIT makes PgSNP wait for user response (see UIRESUME)
% uiwait(handles.figure1);


% --- Outputs from this function are returned to the command line.
function varargout = PgSNP_OutputFcn(hObject, eventdata, handles) 
% varargout  cell array for returning output args (see VARARGOUT);
% hObject    handle to figure
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Get default command line output from handles structure
varargout{1} = handles.output;


% --- Executes on button press in CreatePgSNPButton.
function CreatePgSNPButton_Callback(hObject, eventdata, handles)
% hObject    handle to CreatePgSNPButton (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
path1=get(handles.Directory,'String');
if isfield(handles,'cell')==0
     h = msgbox('Please select a file. For more information see our manual page at http://www.tau.ac.il/~nshomron/GenomeGems/Manual.html','Missing Information','error')
end
f=handles.cell;
 GenerateChrFile(handles.Files{f,2},handles.Files{f,4},handles.Files{f,1});
 if strcmp(path1,'Select Location')==1
     h = msgbox('Please select a location. For more information see our manual page at http://www.tau.ac.il/~nshomron/GenomeGems/Manual.html','Missing Information','error')
end
 GeneratePgSNPFile(handles.Files{f,2},handles.Files{f,1},path1);

% --- Executes during object creation, after setting all properties.
function axes1_CreateFcn(hObject, eventdata, handles)
% hObject    handle to axes1 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called
imshow('PgSNPTitle.jpg')
axis image

% Hint: place code in OpeningFcn to populate axes1


% --- Executes during object creation, after setting all properties.
function SelectFilesTable_CreateFcn(hObject, eventdata, handles)
% hObject    handle to SelectFilesTable (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called
hGenomeGems=getappdata(0,'hGenomeGems');
handles.Files=getappdata(hGenomeGems,'Files');
guidata(hObject, handles);
handles.SelectFilesTable=hObject;
set(handles.SelectFilesTable, 'Data',handles.Files);
guidata(hObject,handles);


% --- Executes when selected cell(s) is changed in SelectFilesTable.
function SelectFilesTable_CellSelectionCallback(hObject, eventdata, handles)
% hObject    handle to SelectFilesTable (see GCBO)
% eventdata  structure with the following fields (see UITABLE)
%	Indices: row and column indices of the cell(s) currently selecteds
% handles    structure with handles and user data (see GUIDATA)
index=eventdata.Indices;
handles.cell = index(1);
guidata(hObject, handles);


% --- Executes during object creation, after setting all properties.
function CreatePgSNPButton_CreateFcn(hObject, eventdata, handles)
% hObject    handle to CreatePgSNPButton (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called



function Directory_Callback(hObject, eventdata, handles)
% hObject    handle to Directory (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
dir=get(hObject,'String');
set(handles.Directory,'String',dir)
a=6;

% Hints: get(hObject,'String') returns contents of Directory as text
%        str2double(get(hObject,'String')) returns contents of Directory as a double


% --- Executes during object creation, after setting all properties.
function Directory_CreateFcn(hObject, eventdata, handles)
% hObject    handle to Directory (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called
handles.Directory=hObject;
guidata(hObject,handles);

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end


% --- Executes on button press in Browse.
function Browse_Callback(hObject, eventdata, handles)
% hObject    handle to Browse (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
directory_name=uigetdir;
set(handles.Directory,'String',directory_name);
a=5;


% --- Executes on button press in CustomTracks.
function CustomTracks_Callback(hObject, eventdata, handles)
% hObject    handle to CustomTracks (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
web http://genome.ucsc.edu/cgi-bin/hgCustom?hgsid=246334113 -browser
